@@ -45,6 +45,8 @@ expect_snapshot_plot <- function(x, name) {
 expect_snapshot_data <- function(x, name) {
   testthat::skip_on_ci()
   testthat::skip_on_os("windows")
+  fun <- function(x) signif(x, digits = 12)
+  x <- dplyr::mutate(x, dplyr::across(where(is.numeric), fun))
   path <- save_csv(x)
   testthat::expect_snapshot_file(path, paste0(name, ".csv"))
 }
